/*
 * FILE --- fms.hh
 *
 * PURPOSE --- Header file for a class that provides an example of usage
 * of the Limitied Lookeahead Policy (LLP) controller. It simulates a load 
 * blanacing problem in a six machine Flexible Manufacturing System (FMS).
 *
 */

// Prevent Multiple Inclusion
#ifndef FMS_HH
#define FMS_HH

// Include Files
#include <stdlib.h>
#include "llp.hh"

// Local Definitions

class FMS: public LLP
{
public:
  // Constructor
  FMS(int _plant_order, int _ctrl_order, 
      int _lookahead_horizon, int _num_diff_ctrl);
  
  // Destructor
  ~FMS();
  
  // Finds the cost of applying the control _control at state _state
  // It should contain the implementation of the cost function as 
  // cost = J(x,u), where x is the state and u is the control input.
  // Overloaded from the base class.
  double find_cost(const double *_state, const double *_control);
  
  // This function should contain the dynamics of the system in the form
  // x(k+1) = F(x(k),u(k)), where x(k) is the state and u(k) is the control 
  // input at time k. The next state x(k+1) is calculated within the function 
  // and returned within the argument _next_state. 
  // Overloaded from the base class.
  void dynamics(const double *_state, const double *_control, double *_next_state);
  
  // Set the state of the system to the specified value
  void set_state(const double *_state);
  
  double *balanced_state; // Desired balanced system states
  
private:
  // Given the initial state find the balanced state
  void find_balanced_state(void);
};

#endif // FMS_HH
